pyo3 = { version = "0.27.0", features = ["extension-module", "abi3-py38"] }
pyo3-asyncio = { version = "0.21", features = ["tokio-runtime"] }
tokio = { version = "1", features = ["full"] }
up-rust = { git = "https://github.com/eclipse-uprotocol/up-rust.git" }
protobuf = "3"
async-trait = "0.1"